@@ -11,6 +11,7 @@ from flowui.utils.enum_types import DeployModeType
 from flowui.exceptions.exceptions import InvalidOperatorOutputError
 # from flowui.client.fs_client import FileSystemClient
 import time
+import subprocess
 
 
 class BaseOperator(metaclass=abc.ABCMeta):
@@ -305,6 +306,49 @@ class BaseOperator(metaclass=abc.ABCMeta):
         # Run operator function
         return cls.operator_function(self=dry_instance, input_model=input_model_obj)
 
+    @staticmethod
+    def get_container_cpu_limit() -> float:
+        """
+        Get the CPU limit of the container in millicores.
+        reference: https://stackoverflow.com/questions/65551215/get-docker-cpu-memory-limit-inside-container/65554131#65554131
+        """
+        with open("/sys/fs/cgroup/cpu/cpu.cfs_quota_us") as fp:
+            cfs_quota_us = int(fp.read())
+        with open("/sys/fs/cgroup/cpu/cpu.cfs_period_us") as fp:
+            cfs_period_us = int(fp.read())
+
+        container_cpus = float(cfs_quota_us / cfs_period_us)
+        return container_cpus
+
+    @staticmethod
+    def get_nvidia_smi_output() -> str:
+        """
+        Get the output of nvidia-smi command.
+        """
+        try:
+            nvidia_smi_output = subprocess.check_output(["nvidia-smi", "-q"])
+            return nvidia_smi_output
+        except Exception as e:
+            raise Exception(f"Error while running nvidia-smi: {e}")
+
+    @staticmethod
+    def get_container_memory_limit() -> int:
+        """
+        Get the memory limit of the container in bytes.
+        """
+        with open("/sys/fs/cgroup/memory/memory.limit_in_bytes") as fp:
+            container_memory_limit = int(fp.read())
+        return container_memory_limit
+
+    @staticmethod
+    def get_container_memory_usage() -> int:
+        """
+        Get the memory usage of the container in bytes.
+        """
+        with open("/sys/fs/cgroup/memory/memory.usage_in_bytes") as fp:
+            container_memory_usage = int(fp.read())
+        return container_memory_usage
+
 
     @abc.abstractmethod
     def operator_function(self):
